#!/usr/bin/env python

import asyncio
import logging

import websockets


async def delayed_ping(websocket):
    await asyncio.sleep(0.3)
    await websocket.ping()


async def generate_data():
    for i in range(10):
        yield str(i) * 1000
        await asyncio.sleep(0.1)


async def do_it():
    websocket = await websockets.connect('ws://127.0.0.1:8088/ws', subprotocols=['echo'])
    await asyncio.gather(websocket.send(generate_data()), delayed_ping(websocket))
    await websocket.recv()
    await websocket.close(code=1002, reason='bye')


if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG)

    loop = asyncio.get_event_loop()
    loop.run_until_complete(do_it())
